==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/sites/lang/sites_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En attente', # NEW
	'articles_meme_auteur' => 'Tous les articles de cet auteur', # NEW
	'articles_off' => 'Bloqués', # NEW
	'articles_publie' => 'Publiés', # NEW
	'articles_refuse' => 'Supprimés', # NEW
	'articles_tous' => 'Tous', # NEW
	'aucun_article_syndic' => 'Aucun article syndiqué', # NEW
	'avis_echec_syndication_01' => 'La sindicacion a pas capitat: lo backend indicat es indeschifrable ò prepaua minga d\'article.',
	'avis_echec_syndication_02' => 'La sindicacion a pas capitat: impossible d\'accedir au backend d\'aqueu sit.',
	'avis_site_introuvable' => 'Sit introbable',
	'avis_site_syndique_probleme' => 'Atencion : la sindicacion d\'aqueu sit a encontrat un problema ; lo sistema es doncas temporarament interromput per aüra. Verificatz l\'adreça dau fichier de sindicacion d\'aqueu sit (<b>@url_syndic@</b>), e provatz mai una recuperacion dei informacions.',
	'avis_sites_probleme_syndication' => 'Aquelu sits an encontrat un problema de sindicacion',
	'avis_sites_syndiques_probleme' => 'Aquelu sits sindicats an pauat un problema',

	// B
	'bouton_exporter' => 'Exporter', # NEW
	'bouton_importer' => 'Importer', # NEW
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion à priòri', # MODIF
	'bouton_radio_non_syndication' => 'Minga de sindicacion', # essai commentaire
	'bouton_radio_syndication' => 'Sindicacion:',

	// C
	'confirmer_purger_syndication' => 'Êtes-vous certain de vouloir supprimer tous les articles syndiqués de ce site ?', # NEW

	// E
	'entree_adresse_fichier_syndication' => 'Adreça dau fichier de sindicacion:',
	'entree_adresse_site' => '<b>Adreça dau sit</b> [Obligatòri]',
	'entree_description_site' => 'Descripcion dau sit',
	'erreur_fichier_format_inconnu' => 'Le format du fichier @fichier@ n\'est pas pris en charge.', # NEW
	'erreur_fichier_incorrect' => 'Impossible de lire le fichier.', # NEW

	// F
	'form_prop_nom_site' => 'Nom dau sit',

	// I
	'icone_article_syndic' => 'Article syndiqué', # NEW
	'icone_articles_syndic' => 'Articles syndiqués', # NEW
	'icone_controler_syndication' => 'Publication des articles syndiqués', # NEW
	'icone_modifier_site' => 'Modificar aqueu sit',
	'icone_referencer_nouveau_site' => 'Referençar un novèu sit',
	'icone_site_reference' => 'Sites référencés', # NEW
	'icone_supprimer_article' => 'Supprimer cet article', # NEW
	'icone_supprimer_articles' => 'Supprimer ces articles', # NEW
	'icone_valider_article' => 'Valider cet article', # NEW
	'icone_valider_articles' => 'Valider ces articles', # NEW
	'icone_voir_sites_references' => 'Veire lu sits referençats',
	'info_1_site_importe' => '1 site a été importé', # NEW
	'info_a_valider' => '[de validar]',
	'info_aucun_site_importe' => 'Aucun site n\'a pu être importé', # NEW
	'info_bloquer' => 'blocar',
	'info_bloquer_lien' => 'Blocar aquel estac',
	'info_derniere_syndication' => 'La darriera sindicacion d\'aqueu sit si faguèt lo',
	'info_liens_syndiques_1' => 'estacs sindicats',
	'info_liens_syndiques_2' => 'son en aspèra de validacion.',
	'info_nb_sites_importes' => '@nb@ sites ont été importés', # NEW
	'info_nom_site_2' => '<b>Nom dau sit</b> [Obligatòri]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'problèma de',
	'info_question_proposer_site' => 'Cu pòu prepauar de sits referençats?',
	'info_retablir_lien' => 'Tornar establir aquel estac',
	'info_site_attente' => 'Sit web en aspèra de validacion',
	'info_site_propose' => 'Sit prepauat lo :',
	'info_site_reference' => 'Sit referençat en linha',
	'info_site_refuse' => 'Sit web refudat',
	'info_site_syndique' => 'Aqueu sit es sindicat...', # MODIF
	'info_site_valider' => 'Sits de validar',
	'info_sites_referencer' => 'Referençar un sit',
	'info_sites_refuses' => 'Lu sits refudats',
	'info_statut_site_1' => 'Aqueu sit es :',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Prepauat',
	'info_statut_site_4' => 'Au bordilhier', # MODIF
	'info_syndication' => 'sindicacion:',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Blocar lu estacs sindicats per validacion',
	'item_gerer_annuaire_site_web' => 'Gerar un annuari de sits web',
	'item_non_bloquer_liens_syndiques' => 'Blocar pas lu ligams eissuts de la sindicacion',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l\'annuari de sits web',
	'item_non_utiliser_syndication' => 'Utilisar pas la sindicacion automatica',
	'item_utiliser_syndication' => 'Utilisar la sindicacion automatica',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exporter les mots-clés sous forme de tags', # NEW
	'label_exporter_id_parent' => 'Exporter les sites de la rubrique', # NEW
	'label_exporter_publie_seulement_1' => 'Exporter uniquement les sites publiés', # NEW
	'label_fichier_import' => 'Fichier HTML', # NEW
	'label_importer_les_tags_1' => 'Importer les tags sous forme de mot-clé', # NEW
	'label_importer_statut_publie_1' => 'Publier automatiquement les sites', # NEW
	'lien_mise_a_jour_syndication' => 'Actualisar aüra',
	'lien_nouvelle_recuperation' => 'Temptar una novèla recuperacion de li donadas',
	'lien_purger_syndication' => 'Effacer tous les articles syndiqués', # NEW

	// N
	'nombre_articles_syndic' => '@nb@ articles syndiqués', # NEW

	// S
	'statut_off' => 'Supprimé', # NEW
	'statut_prop' => 'En attente', # NEW
	'statut_publie' => 'Publié', # NEW
	'syndic_choix_moderation' => 'Que faire dei estacs venentsen provenença d\'aquèu sit ?',
	'syndic_choix_oublier' => 'Que faire dei estacs que figuran pas plus dins lo fichièr de syndicacion ?',
	'syndic_choix_resume' => 'Certen sites difusan lo tèxt complet dei articles. Quora aqueste es disponible, desiratz de lo sindicar? :',
	'syndic_lien_obsolete' => 'Estac vielh',
	'syndic_option_miroir' => 'li blocar automaticament',
	'syndic_option_oubli' => 'li efaçar (après @mois@ mes)',
	'syndic_option_resume_non' => 'lo contengut complet dei articles (au format HTML)',
	'syndic_option_resume_oui' => 'un simple resumit (au format tèxte)',
	'syndic_options' => 'Opcions de syndicacion :',

	// T
	'texte_expliquer_export_bookmarks' => 'Vous pouvez exporter une liste de sites au format Marque-page HTML,
	pour vous permettre ensuite de l\'importer dans votre navigateur ou dans un service en ligne', # NEW
	'texte_expliquer_import_bookmarks' => 'Vous pouvez importer une liste de sites au format Marque-page HTML,
	en provenance de votre navigateur ou d\'un service en ligne de gestion des Marques-pages.', # NEW
	'texte_liens_sites_syndiques' => 'Lu ligams eissits dei sits sindicats si poadon
   blocar à priòri; lo reglatge
  çai sota indica lo reglatge predefinit dei
   sits sindicats après la sieu creacion. De tota maniera,
    es possible pi de 
   desblocar cada ligam individualament, ò de
   chausir, sit per sit, de blocar lu ligams avenidors
   de tau ò tau sit.', # MODIF
	'texte_messages_publics' => 'Messatges publics de l\'article:',
	'texte_non_fonction_referencement' => 'Podètz chausir d\'utilisar pas aquela foncion automatica, e indicar de vos meme lu elements que tòcan aqueu sit...', # MODIF
	'texte_referencement_automatique' => '<b>Referençament automatisat d\'un sit</b><br />Podètz referençar leu un sit web en indicant çai sota l\'adreça URL desirada, ò l\'adreça dau sieu fichier de sindicacion. SPIP agantarà automaticament li informacions que concernisson aqueu sit (titre, descripcion...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Veuillez vérifier les informations fournies par <tt>@url@</tt> avant d\'enregistrer.', # NEW
	'texte_syndication' => 'Si pòu recuperar automaticament, quora un sit web lo permet, 
  la tièra dei sieus noveutats. Per far aquò, vos cau activar la sindicacion. 
  <blockquote><i>D\'unu aubergadors activon pas aquela foncionalitat; 
  dins aqueu cas, podretz pas utilisar la sindicacion de contengut
  despí lo voastre sit.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles sindicats tirats d\'aqueu sit',
	'titre_dernier_article_syndique' => 'Darriers articles sindicats',
	'titre_exporter_bookmarks' => 'Exporter des Marques-pages', # NEW
	'titre_importer_bookmarks' => 'Importer des Marques-pages', # NEW
	'titre_importer_exporter_bookmarks' => 'Importer et Exporter des Marques-pages', # NEW
	'titre_page_sites_tous' => 'Lu sits referençats',
	'titre_referencement_sites' => 'Referençament de sits e sindicacion',
	'titre_site_numero' => 'SIT NÚMERO :',
	'titre_sites_proposes' => 'Lu sits prepauats',
	'titre_sites_references_rubrique' => 'Lu sits referençats dins aquela rubrica',
	'titre_sites_syndiques' => 'Lu sits sindicats',
	'titre_sites_tous' => 'Lu sits referençats',
	'titre_syndication' => 'Sindicacion dei sits',
	'tout_voir' => 'Voir tous les articles syndiqués', # NEW

	// U
	'un_article_syndic' => '1 article syndiqué' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/sites/lang/sites_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'La sindicacion a pas capitat: lo backend indicat es indeschifrable ò prepaua minga d’article.',
	'avis_echec_syndication_02' => 'La sindicacion a pas capitat: impossible d’accedir au backend d’aqueu sit.',
	'avis_site_introuvable' => 'Sit introbable',
	'avis_site_syndique_probleme' => 'Atencion : la sindicacion d’aqueu sit a encontrat un problema ; lo sistema es doncas temporarament interromput per aüra. Verificatz l’adreça dau fichier de sindicacion d’aqueu sit (<b>@url_syndic@</b>), e provatz mai una recuperacion dei informacions.',
	'avis_sites_probleme_syndication' => 'Aquelu sits an encontrat un problema de sindicacion',
	'avis_sites_syndiques_probleme' => 'Aquelu sits sindicats an pauat un problema',

	// B
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion à priòri', # MODIF
	'bouton_radio_non_syndication' => 'Minga de sindicacion', # essai commentaire
	'bouton_radio_syndication' => 'Sindicacion:',

	// E
	'entree_adresse_fichier_syndication' => 'Adreça dau fichier de sindicacion:',
	'entree_adresse_site' => '<b>Adreça dau sit</b> [Obligatòri]',
	'entree_description_site' => 'Descripcion dau sit',

	// F
	'form_prop_nom_site' => 'Nom dau sit',

	// I
	'icone_modifier_site' => 'Modificar aqueu sit',
	'icone_referencer_nouveau_site' => 'Referençar un novèu sit',
	'icone_voir_sites_references' => 'Veire lu sits referençats',
	'info_1_site' => '1 sit',
	'info_a_valider' => '[de validar]',
	'info_bloquer' => 'blocar',
	'info_bloquer_lien' => 'Blocar aquel estac',
	'info_derniere_syndication' => 'La darriera sindicacion d’aqueu sit si faguèt lo',
	'info_liens_syndiques_1' => 'estacs sindicats',
	'info_liens_syndiques_2' => 'son en aspèra de validacion.',
	'info_nom_site_2' => '<b>Nom dau sit</b> [Obligatòri]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'problèma de',
	'info_question_proposer_site' => 'Cu pòu prepauar de sits referençats?',
	'info_retablir_lien' => 'Tornar establir aquel estac',
	'info_site_attente' => 'Sit web en aspèra de validacion',
	'info_site_propose' => 'Sit prepauat lo :',
	'info_site_reference' => 'Sit referençat en linha',
	'info_site_refuse' => 'Sit web refudat',
	'info_site_syndique' => 'Aqueu sit es sindicat...', # MODIF
	'info_site_valider' => 'Sits de validar',
	'info_sites_referencer' => 'Referençar un sit',
	'info_sites_refuses' => 'Lu sits refudats',
	'info_statut_site_1' => 'Aqueu sit es :',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Prepauat',
	'info_statut_site_4' => 'Au bordilhier', # MODIF
	'info_syndication' => 'sindicacion:',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Blocar lu estacs sindicats per validacion',
	'item_gerer_annuaire_site_web' => 'Gerar un annuari de sits web',
	'item_non_bloquer_liens_syndiques' => 'Blocar pas lu ligams eissuts de la sindicacion',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’annuari de sits web',
	'item_non_utiliser_syndication' => 'Utilisar pas la sindicacion automatica',
	'item_utiliser_syndication' => 'Utilisar la sindicacion automatica',

	// L
	'lien_mise_a_jour_syndication' => 'Actualisar aüra',
	'lien_nouvelle_recuperation' => 'Temptar una novèla recuperacion de li donadas',

	// S
	'syndic_choix_moderation' => 'Que faire dei estacs venentsen provenença d’aquèu sit ?',
	'syndic_choix_oublier' => 'Que faire dei estacs que figuran pas plus dins lo fichièr de syndicacion ?',
	'syndic_choix_resume' => 'Certen sites difusan lo tèxt complet dei articles. Quora aqueste es disponible, desiratz de lo sindicar? :',
	'syndic_lien_obsolete' => 'Estac vielh',
	'syndic_option_miroir' => 'li blocar automaticament',
	'syndic_option_oubli' => 'li efaçar (après @mois@ mes)',
	'syndic_option_resume_non' => 'lo contengut complet dei articles (au format HTML)',
	'syndic_option_resume_oui' => 'un simple resumit (au format tèxte)',
	'syndic_options' => 'Opcions de syndicacion :',

	// T
	'texte_liens_sites_syndiques' => 'Lu ligams eissits dei sits sindicats si poadon
   blocar à priòri; lo reglatge
  çai sota indica lo reglatge predefinit dei
   sits sindicats après la sieu creacion. De tota maniera,
    es possible pi de 
   desblocar cada ligam individualament, ò de
   chausir, sit per sit, de blocar lu ligams avenidors
   de tau ò tau sit.', # MODIF
	'texte_messages_publics' => 'Messatges publics de l’article:',
	'texte_non_fonction_referencement' => 'Podètz chausir d’utilisar pas aquela foncion automatica, e indicar de vos meme lu elements que tòcan aqueu sit...', # MODIF
	'texte_referencement_automatique' => '<b>Referençament automatisat d’un sit</b><br />Podètz referençar leu un sit web en indicant çai sota l’adreça URL desirada, ò l’adreça dau sieu fichier de sindicacion. SPIP agantarà automaticament li informacions que concernisson aqueu sit (titre, descripcion...).', # MODIF
	'texte_syndication' => 'Si pòu recuperar automaticament, quora un sit web lo permet, 
  la tièra dei sieus noveutats. Per far aquò, vos cau activar la sindicacion. 
  <blockquote><i>D’unu aubergadors activon pas aquela foncionalitat; 
  dins aqueu cas, podretz pas utilisar la sindicacion de contengut
  despí lo voastre sit.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles sindicats tirats d’aqueu sit',
	'titre_dernier_article_syndique' => 'Darriers articles sindicats',
	'titre_page_sites_tous' => 'Lu sits referençats',
	'titre_referencement_sites' => 'Referençament de sits e sindicacion',
	'titre_site_numero' => 'SIT NÚMERO :',
	'titre_sites_proposes' => 'Lu sits prepauats',
	'titre_sites_references_rubrique' => 'Lu sits referençats dins aquela rubrica',
	'titre_sites_syndiques' => 'Lu sits sindicats',
	'titre_sites_tous' => 'Lu sits referençats',
	'titre_syndication' => 'Sindicacion dei sits'
);

?>
